@@ -20,12 +20,11 @@ logger = logging.getLogger(__name__)
 
 
 class ValdError(LineListError):
-    """ Vald Data File Error """
+    """Vald Data File Error"""
 
 
 class ValdFile(LineList):
-    """Atomic data for a list of spectral lines.
-    """
+    """Atomic data for a list of spectral lines."""
 
     citation_info = r"""
     @ARTICLE{2015PhyS...90e4005R,
@@ -414,7 +413,8 @@ class ValdFile(LineList):
             # extract error data
             error = np.array([s[:10].strip() for s in comment])
             error = LineList.parse_line_error(
-                error, linelist["depth"] if valdtype == "extract_stellar" else None
+                error,
+                linelist["depth"] if valdtype == "extract_stellar" else None,
             )
             linelist["error"] = error
 
